@@ -1,22 +1,30 @@
-#ifndef _BITS_H_
-#define _BITS_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/kernel/bstruct/givbits.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Author: T. Gautier
-// $Id: givbits.h,v 1.1.1.1 2004/05/12 16:08:24 jgdumas Exp $
+// $Id: givbits.h,v 1.3 2011-02-02 16:23:55 bboyer Exp $
 // ==========================================================================
-// Description: 
-// - field of n bits, for any n
+/** @file givbits.h
+ * @ingroup bstruct
+ * @brief field of n bits, for any n
+ */
+#ifndef __GIVARO_bits_H
+#define __GIVARO_bits_H
 
 #include <iostream>
 #include "givaro/givaromm.h"
 #include "givaro/givarray0.h"
 
+namespace Givaro {
+
+	//! Bits.
 class Bits {
 public:
-  typedef unsigned long base ;
+  typedef size_t base ;
 
   Bits () ;
   Bits (const size_t n) ; // -- n is the number of bits reclaimed
@@ -25,19 +33,19 @@ public:
 
   // -- All binary operand must have same type:
   // <op>in are for inplace operator (this receives the result)
-  
+
   const Bits operator&( const Bits& A ) const ;
   Bits& andin( const Bits& A, const Bits B) ;
   Bits& operator&= (const Bits& A) ;
   //inline const Bits operator& (const Bits& A) const { return operator&(A) ; }
 
-  // -- Or 
+  // -- Or
   const Bits operator|( const Bits& A ) const ;
   Bits& orin( const Bits& A, const Bits B) ;
   Bits& operator|=( const Bits& A )  ;
   //inline const Bits operator| (const Bits& A) const { return operator|(A) ; }
 
-  // -- Or 
+  // -- Or
   const Bits operator^( const Bits& A ) const ;
   Bits& xorin( const Bits& A, const Bits B) ;
   Bits& operator^=( const Bits& A )  ;
@@ -58,12 +66,12 @@ public:
   // -- Returns the number of non zero bits :
   long numone() const ;
 
-  // -- Returns the index of non zero bits 
+  // -- Returns the index of non zero bits
   void indexofone( Array0<Bits::base>& ) const ;
 
   // -- Returns the length (in bit) of this :
   size_t length() const ;
-  
+
   // -- set to 0 all bits:
   void clear() ;
   // -- set to 0 the i-th bit
@@ -75,6 +83,7 @@ public:
   // -- returns the i-th bit
   int  get(const int i) const ;
   int  operator[] (const int i) const ;
+  int  operator[] (const size_t i) const ;
 
   // -- IO/methods
   std::ostream& print( std::ostream& o ) const ;
@@ -87,10 +96,12 @@ protected:
 private:
   static GivModule Module;
   friend class GivModule;
-  static void Init(int*, char***);  
+  static void Init(int*, char***);
   static void End();
 } ;
 
+} // namespace Givaro
+
 #include "givaro/givbits.inl"
 
-#endif
+#endif // __GIVARO_bits_H
