@@ -1,19 +1,30 @@
-#ifndef _LIST0_H_
-#define _LIST0_H_
-// ========================================================================== 
+// ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/kernel/bstruct/givlist0.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Author: T. Gautier
-// $Id: givlist0.h,v 1.1.1.1 2004/05/12 16:08:24 jgdumas Exp $
-// ========================================================================== 
-// Description:
-// List of type T with double link and various insert/get/rmv method.
-// Used reference counting on each node of the list.
+// $Id: givlist0.h,v 1.3 2011-02-02 16:23:55 bboyer Exp $
+// ==========================================================================
+
+/*! @file givlist0.h
+ * @ingroup bstruct
+ * @brief List of type T with double link and various insert/get/rmv method.
+ * Used reference counting on each node of the list.
+ */
+
+#ifndef __GIVARO_list0_H
+#define __GIVARO_list0_H
 
 #include "givaro/givbasictype.h"
 #include "givaro/giverror.h"
 
+
+namespace Givaro {
+
+	//! ListO
 template <class T>
 class List0 {
 public :
@@ -32,13 +43,13 @@ public :
   // -- Physical copy operator
   List0<T>& copy(const List0<T>& p);
 
-  // -- Logical recopy operator 
+  // -- Logical recopy operator
   List0<T>& logcopy(const List0<T>& p);
-  
+
   // -- Logical recopy
   List0<T>& operator= (const List0<T>& p);
 
-  // -- Return 1 if the list is empty or 0 
+  // -- Return 1 if the list is empty or 0
   int is_empty() const;
 
   // -- Return the occuped size of the list
@@ -65,8 +76,8 @@ public:
       GivaroMM<T>::desallocate(item,1);
       GivaroMM<int>::desallocate(cnt,1);
     }
-    node* next; 
-    node* prev; 
+    node* next;
+    node* prev;
     T* item;
     int* cnt;     // reference counter on item
   };
@@ -93,6 +104,8 @@ protected :  // --------------------- Public Internal representation
   node*  _queue;  // queue of the list
 };
 
+} // namespace Givaro
+
 #include "givaro/givlist0.inl"
 
-#endif
+#endif // __GIVARO_list0_H
