@@ -1,25 +1,33 @@
-#ifndef _GIV_INIT_H_
-#define _GIV_INIT_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/kernel/system/givinit.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givinit.h,v 1.1.1.1 2004/05/12 16:08:24 jgdumas Exp $
+// $Id: givinit.h,v 1.3 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
+/** @file givinit.h
+ * @ingroup system
+ * @brief NO DOC
+ */
+#ifndef __GIVARO_init_H
+#define __GIVARO_init_H
 #include "givaro/givconfig.h"
 #include <iostream>
 
+//! Namespace in which the whole Givaro library resides.
+namespace Givaro {
 
 // ==========================================================================
-// --
-// -- Description:
-//   - Initialisation of GIVARO :
-//     * handler to manage signal 
-//     * init the memory manager
-//     * init all other modules
-
-class Givaro {
+	/**  Initialisation of GIVARO .
+	 * - handler to manage signal
+	 * - init the memory manager
+	 * - init all other modules
+	 * .
+	 */
+class GivaroMain {
 public:
   //- Init of Givaro kernel :
 static void Init(int* argc, char*** argv) ;
@@ -39,9 +47,9 @@ static void DisplayVersion();
 
 // ==========================================================================
 // --
-// -- Main application class
-// -- Could be not used
-class GivaroAppli : public Givaro {
+//! Main application class
+//! Could be not used
+class GivaroAppli : public GivaroMain {
 public:
   //- Cstor, destor
   GivaroAppli() {};
@@ -54,4 +62,6 @@ public:
   int run( int argc=0, char** argv=0);
 };
 
-#endif
+} // namespace Givaro
+#endif // __GIVARO_init_H
+// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
