@@ -1,28 +1,37 @@
-#ifndef _MODULE_INIT_H_
-#define _MODULE_INIT_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/kernel/system/givmodule.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givmodule.h,v 1.2 2005/07/13 09:59:37 pernet Exp $
+// $Id: givmodule.h,v 1.4 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
-// Description:
+/** @file givmodule.h
+ * @ingroup system
+ * @brief NO DOC
+ */
+#ifndef __GIVARO_module_init_H
+#define __GIVARO_module_init_H
+
+namespace Givaro {
 
 // -------------------------------------------------------- Fwd declaration
 
 class GivModule;
 
 
-// ----------------------------------------------------------- GivaroNoInit:
-// Purpose: used to delay construction of object in the init function
-// of a module definition.
-
+//! GivaroNoInit.
+/**
+ * Purpose: used to delay construction of object in the init function
+ of a module definition.
+ */
 class GivaroNoInit {};
 
 
-// -------------------------------------------------------------- InitAfter:
-// Purpose: define a precedence relation between two modules.
+//! InitAfter.
+//! Purpose: define a precedence relation between two modules.
 
 class InitAfter {
 public:
@@ -39,9 +48,9 @@ private:
 };
 
 
-// -------------------------------------------------------------- GivModule:
-// Purpose: definition of module with precedence relation use to initialize
-// them between different units compilation.
+//! GivModule.
+//! Purpose: definition of module with precedence relation use to initialize
+//! them between different units compilation.
 
 class GivModule {
 public:
@@ -66,9 +75,9 @@ private:
   // - Call by the Givaro::Init and Givaro::End functions
 static void InitApp(int* argc, char***argv);
 static void EndApp();
-friend class Givaro;
+friend class GivaroMain;
 
-private: 
+private:
   // - Internal data of a module
   int priority;
   InitAfter which;
@@ -81,9 +90,9 @@ static void SortGivModule();
 };
 
 
-// -------------------------------------------------------------- GivModule:
-// Purpose: definition of object to be initialized after all modules
-// initialization
+//! GivModule.
+//! Purpose: definition of object to be initialized after all modules
+//! initialization
 
 class ObjectInit {
 public:
@@ -97,4 +106,6 @@ private:
   friend class GivModule;
 };
 
-#endif
+} // namespace Givaro
+#endif // __GIVARO_module_init_H
+// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
