@@ -1,39 +1,52 @@
-#ifndef _GIV_PERF_H_
-#define _GIV_PERF_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/kernel/system/givperf.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givperf.h,v 1.1.1.1 2004/05/12 16:08:24 jgdumas Exp $
+// $Id: givperf.h,v 1.3 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
-// Description:
-// - performance analysis
+/** @file givperf.h
+ * @ingroup system
+ * @brief performance analysis
+ */
+#ifndef __GIVARO_perf_H
+#define __GIVARO_perf_H
 
 #ifdef GIVARO_PERF
 #include <stddef>
 #include <iostream>
 
+namespace Givaro {
 
+	//! cout counter
 struct __CoutCounter {
   void (*print)(ostream&);
-  __CoutCounter( void (*prn)(ostream& ) ) : print(prn) 
+  __CoutCounter( void (*prn)(ostream& ) ) : print(prn)
   {
     cout << "New Counter" << endl;
   }
-  ~__CoutCounter( ) 
-  { 
+  ~__CoutCounter( )
+  {
     cout << "Destroy a counter" << endl;
-    (*print)(cout << endl); cout << endl; 
+    (*print)(cout << endl); cout << endl;
   }
 };
 
+} // namespace Givaro
 
-// --- Class that store a set of counters:
-// - _count_cstor: #cstor calls except the recopy constructor calls
-// - _count_cstor_recopy: #recopy cstor calls
-// - _count_assign: #assignment calls
-// - _count_dstor: #dstor calls
+
+namespace Givaro {
+/*!@internal
+ * @brief Class that store a set of counters.
+ * - _count_cstor: \#cstor calls except the recopy constructor calls
+ * - _count_cstor_recopy: \#recopy cstor calls
+ * - _count_assign: \#assignment calls
+ * - _count_dstor: \#dstor calls
+ * .
+ */
 
 #define GIVARO_PERF_DEFCLASS(Name,Type)					\
 template<class Type>							\
@@ -79,18 +92,23 @@ __CoutCounter _Giv_perf##Name<Type>::_coutcout= &_Giv_perf##Name<Type>::print;
 
 #define GIVARO_PERF_DISPLAY(Name,Type)  _Giv_perf##Name<Type>::print(cout), cout << endl;
 
+} // namespace Givaro
 
 #else // #ifdef GIVARO_PERF
 
-#define GIVARO_PERF_DEFCLASS(N,T)	
+// namespace Givaro {
+
+#define GIVARO_PERF_DEFCLASS(N,T)
 #define GIVARO_PERF_INEHERIT(N,T)
-#define GIVARO_PERF_CSTOR(Name,Type)  
-#define GIVARO_PERF_RECOPY(Name,Type) 
-#define GIVARO_PERF_DSTOR(Name,Type) 
+#define GIVARO_PERF_CSTOR(Name,Type)
+#define GIVARO_PERF_RECOPY(Name,Type)
+#define GIVARO_PERF_DSTOR(Name,Type)
 #define GIVARO_PERF_ASSIGN(Name,Type)
-#define GIVARO_PERF_DISPLAY(Name,Type)  
+#define GIVARO_PERF_DISPLAY(Name,Type)
 
+// } // namespace Givaro
 
 #endif
+#endif // __GIVARO_perf_H
 
-#endif
+// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
