@@ -26,6 +26,7 @@
 #define __GIVARO_timer_H
 
 #include <iostream>
+#include <givaro/givconfig.h>
 namespace Givaro {
 // class BaseTimer; class RealTimer; class SysTimer; class UserTimer;
 
@@ -229,9 +230,12 @@ inline std::ostream &operator << (std::ostream &o, const Timer &T)
 	if (ut < 0.0000000001) ut = 0;
 	return o << T.realtime() << "s (" << ut << " cpu) [" << T.count() << "]";
 }
+}
 
-#if defined(_OPENMP) || defined(OMP_H) || defined(__OMP_H)
+#ifdef GIVARO_USES_OMP
 #include <omp.h>
+
+namespace Givaro {
 //! OMP timer
 struct OMPTimer {
 	double _c;
@@ -258,9 +262,9 @@ struct OMPTimer {
 	}
 	OMPTimer  operator -() { OMPTimer r; r._c = - _c; return r; }
 };
-#endif
-
 } // namespace Givaro
+#endif // OMP
+
 
 #endif // __GIVARO_timer_H
 // vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
