@@ -1,27 +1,35 @@
-#ifndef _GIVARO_ZPZInteger_H_ 
-#define _GIVARO_ZPZInteger_H_ 
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/kernel/zpz/givzpzInt.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: JG Dumas
-// $Id: givzpzInt.h,v 1.6 2005/07/12 12:54:37 jgdumas Exp $
-// ==========================================================================
-//
-// Description:
-//   Arithmetic on Z/pZ, with p a prime number in arbitrary precision
-
-#include "givbasictype.h"
-#include "giverror.h"
-#include "givzpz.h"
-#include "givinteger.h"
-
-
-// ==========================================================================
-// -- This class implement the standard arithmetic with Modulo Elements:
-// - The representation of an integer a in Zpz is the value a % p
+// $Id: givzpzInt.h,v 1.11 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
 
+/*! @file givzpzInt.h
+ * @ingroup zpz
+ *  @brief Arithmetic on Z/pZ, with p a prime number in arbitrary precision.
+ */
+
+#ifndef __GIVARO_zpz_int_H
+#define __GIVARO_zpz_int_H
+
+#include "givaro/givbasictype.h"
+#include "givaro/giverror.h"
+#include "givaro/givzpztypes.h"
+#include "givaro/givinteger.h"
+#include "givaro/giv_randiter.h"
+
+
+namespace Givaro {
+
+/*! @brief This class implement the standard arithmetic with Modulo Elements.
+ * - The representation of an integer a in Zpz is the value a % p
+ * .
+ */
 template<>
 class ZpzDom<Integer> {
 public:
@@ -36,25 +44,31 @@ public:
   typedef Rep* Array;
   typedef const Rep* constArray;
 
-  // ----- Constantes 
+  // ----- Constantes
   const Rep zero;
   const Rep one;
+  const Rep mOne;
 
-  // ----- Constructor 
-  ZpzDom() : zero(0), one(1), _p(0) {}
-  ZpzDom( Residu_t p ) : zero(0), one(1), _p(p) {}
-  ZpzDom( const ZpzDom<Integer>& F) : zero(0), one(1), _p(F._p) { }
+  // ----- Constructor
+  ZpzDom() : zero(0), one(1), mOne(-1), _p(0) {}
+  ZpzDom( Residu_t p ) : zero(0), one(1), mOne(p-1), _p(p) {}
+  ZpzDom( const ZpzDom<Integer>& F) : zero(F.zero), one(F.one), mOne(F.mOne),_p(F._p) { }
 
 
   int operator==( const ZpzDom<Integer>& BC) const { return _p == BC._p;}
   int operator!=( const ZpzDom<Integer>& BC) const { return _p != BC._p;}
- 
-  ZpzDom<Integer>& operator=( const ZpzDom<Integer>& F) { 
-      this->_p = F._p; 
+
+  ZpzDom<Integer>& operator=( const ZpzDom<Integer>& F) {
+	  F.assign(const_cast<Element&>(one),F.one);
+	  F.assign(const_cast<Element&>(zero),F.zero);
+	  F.assign(const_cast<Element&>(mOne),F.mOne);
+
+
+      this->_p = F._p;
       return *this;
   }
 
-  // ----- Access to the modulus 
+  // ----- Access to the modulus
   Residu_t residu() const;
   Residu_t size() const {return _p;}
   Rep access( const Rep& a ) const { return a; }
@@ -63,7 +77,7 @@ public:
   Residu_t cardinality() const { return _p; }
 
 
-  // ----- Access to the modulus 
+  // ----- Access to the modulus
   Rep& init( Rep& a ) const;
   void init( const size_t, Array a, constArray b ) const;
   Rep& init( Rep& r , const long a) const ;
@@ -80,13 +94,11 @@ public:
   float& convert(float& r, const Rep& a ) const { return r = (float)a ;}
   double& convert(double& r, const Rep& a ) const { return r = (double)a ;}
   long int& convert(long int& r, const Rep& a) const { return r = (long int)a;}
-  unsigned long int& convert(unsigned long int& r, const Rep& a) const { return r = (unsigned long int)a;}
-    Integer& convert(Integer& i, const Rep& a) const {
-        unsigned long ur;
-        return i = (Integer)convert(ur, a);
-    }        
-    
-
+  unsigned long int& convert(unsigned long int& r, const Rep& a) const { return r = (unsigned long int)a;
+  }
+  Integer& convert(Integer& i, const Rep& a) const {
+      return i = a;
+  }
 
   // ----- Misc methods
   int isZero( const Rep& a ) const;
@@ -129,31 +141,33 @@ public:
 
   // -- axpy: r <- a * x + y mod p
   Rep& axpy  (Rep& r, const Rep& a, const Rep& b, const Rep& c) const;
-  void axpy 
-   (const size_t sz, Array r, constArray a, constArray x, constArray c) const;
+  void axpy (const size_t sz, Array r, constArray a, constArray x, constArray c) const;
   // -- axpyin: r <- r + a * x mod p
   Rep& axpyin(Rep& r, const Rep& a, const Rep& b) const;
-  void axpyin 
-   (const size_t sz, Array r, constArray a, constArray x) const;
+  void axpyin (const size_t sz, Array r, constArray a, constArray x) const;
 
   // -- axmy: r <- a * x - y mod p
   Rep& axmy  (Rep& r, const Rep& a, const Rep& b, const Rep& c) const;
-  void axmy 
-   (const size_t sz, Array r, constArray a, constArray x, constArray c) const;
-  // -- axmyin: r <- r - a * x mod p
+  void axmy (const size_t sz, Array r, constArray a, constArray x, constArray c) const;
+  // -- axmyin: r <-  a * x - r mod p
   Rep& axmyin(Rep& r, const Rep& a, const Rep& b) const;
-  void axmyin 
-   (const size_t sz, Array r, constArray a, constArray x) const;
+  // void axmyin (const size_t sz, Array r, constArray a, constArray x) const;
+
+  // -- maxpy: r <- c - a * b mod p
+  Rep& maxpy  (Rep& r, const Rep& a, const Rep& b, const Rep& c) const;
+  // -- maxpyin: r <- r - a * x mod p
+  Rep& maxpyin(Rep& r, const Rep& a, const Rep& b) const;
+  void maxpyin (const size_t sz, Array r, constArray a, constArray x) const;
 
   // -- Misc: r <- a mod p
   void assign ( const size_t sz, Array r, constArray a ) const;
-/* JGD 26.10.99
+#if 0 /* JGD 26.10.99 */
   void assign ( Rep& r, const Rep& a) const;
   void assign ( Rep& r, const long a ) const;
   void assign ( Rep& r, const unsigned long a ) const;
   void assign ( Rep& r, const int a ) const;
   void assign ( Rep& r, const unsigned int a ) const;
-*/
+#endif
   Rep& assign ( Rep& r, const Rep& a) const;
   Rep& assign ( Rep& r, const long a ) const;
   Rep& assign ( Rep& r, const unsigned long a ) const;
@@ -168,24 +182,24 @@ public:
     template< class RandIter > Rep& nonzerorandom(RandIter&, Rep& r) const ;
     template< class RandIter > Rep& nonzerorandom(RandIter&, Rep& r, long s) const ;
     template< class RandIter > Rep& nonzerorandom(RandIter&, Rep& r, const Rep& b) const ;
-    
+
     typedef GIV_randIter< ZpzDom<Integer> , Rep > randIter;
 
   // <- \sum_i a[i], return 1 if a.size() ==0,
-  Rep& reduceadd ( Rep& r, const size_t sz, constArray a ) const; 
+  Rep& reduceadd ( Rep& r, const size_t sz, constArray a ) const;
 
   // <- \prod_i a[i], return 1 if a.size() ==0,
-  Rep& reducemul ( Rep& r, const size_t sz, constArray a ) const; 
+  Rep& reducemul ( Rep& r, const size_t sz, constArray a ) const;
 
-  // <- \sum_i a[i] * b[i] 
-//   Rep& dotprod ( Rep& r, const size_t sz, constArray a, constArray b ) const; 
-//   Rep& dotprod ( Rep& r, const int bound, const size_t sz, constArray a, constArray b ) const; 
+  // <- \sum_i a[i] * b[i]
+//   Rep& dotprod ( Rep& r, const size_t sz, constArray a, constArray b ) const;
+//   Rep& dotprod ( Rep& r, const int bound, const size_t sz, constArray a, constArray b ) const;
 
   // ----- a -> r: Rep to double
-  void i2d ( const size_t sz, double* r, constArray a ) const; 
+  void i2d ( const size_t sz, double* r, constArray a ) const;
 
   // ----- a -> r % p: double to Rep % p
-  void d2i ( const size_t sz, Array r, const double* a ) const; 
+  void d2i ( const size_t sz, Array r, const double* a ) const;
 
   // --- IO methods
   std::istream& read ( std::istream& s );
@@ -201,7 +215,9 @@ protected:
     static void End();
 };
 
+} // namespace Givaro
 
-#include "givzpzInt.inl"
+#include "givaro/givzpzInt.inl"
 
-#endif
+#endif // __GIVARO_zpz_int_H
+// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
