@@ -1,19 +1,29 @@
-#ifndef _GIV_MATRIX_DENSE_H_
-#define _GIV_MATRIX_DENSE_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/library/matrix/givmatdense.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givmatdense.h,v 1.2 2005/06/14 14:53:14 pernet Exp $
+// $Id: givmatdense.h,v 1.4 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
 // Description:
 // of matrix by blocks.
+//
+
+#error "dead code"
+
+#ifndef _GIV_MATRIX_DENSE_H_
+#define _GIV_MATRIX_DENSE_H_
 
 #include "givaro/givmatrix.h"
 #include "givaro/givmatstoragedense.h"
 
 
+namespace Givaro {
+#pragma message "#warning this file will probably not compile"
+
 // --
 // -- Matrix class: dense matrix
 // --
@@ -34,7 +44,7 @@ public:
   // -- Self_t
   typedef          MatrixDom<Domain, Dense>                     Self_t;
 
-  //-- Dstor: 
+  //-- Dstor:
   ~MatrixDom() {}
 
   //-- Default cstor:
@@ -54,13 +64,13 @@ public:
   { r.allocate(0); }
 
   //-- access operators:
-  Type_t& operator() (Rep& r, Indice_t i, Indice_t j) const 
+  Type_t& operator() (Rep& r, Indice_t i, Indice_t j) const
   { return r(i,j); }
-  const Type_t& operator() (const Rep& r, Indice_t i, Indice_t j) const 
+  const Type_t& operator() (const Rep& r, Indice_t i, Indice_t j) const
   { return r(i,j); }
 
   //-- Assignment operator: physical copy
-  void assign (Rep& r, const Rep& a) 
+  void assign (Rep& r, const Rep& a)
   { r.copy(a); }
 
   // -- Comparaizon
@@ -84,14 +94,14 @@ public:
   void neg   ( Rep& res, const Rep& u ) const;
 
   // --- Mul Vect:
-  void mul   ( typename VectorDom<Domain,Dense>::Rep& res, const Rep& M, 
+  void mul   ( typename VectorDom<Domain,Dense>::Rep& res, const Rep& M,
                const VectorDom<Domain,Dense>& VD,
                const typename VectorDom<Domain,Dense>::Rep& u ) const;
-  void multrans ( typename VectorDom<Domain,Dense>::Rep& res, const Rep& M, 
+  void multrans ( typename VectorDom<Domain,Dense>::Rep& res, const Rep& M,
                   const VectorDom<Domain,Dense>& VS,
                   const typename VectorDom<Domain,Dense>::Rep& u ) const;
 
-  // -- axpy operations K-Space: 
+  // -- axpy operations K-Space:
   // r <- a*x+y
   void axpy  ( Rep& res, const Type_t& a, const Rep& x, const Rep& y )const;
   // r <- r+a*x
@@ -101,10 +111,10 @@ public:
   // r <- r-a*x
   void axmyin( Rep& res, const Type_t& a, const Type_t& x ) const;
 
-  // a*A*X + bY 
-  void axpy  ( Rep& res, const Type_t& a, const Rep& A, const Rep& X, 
+  // a*A*X + bY
+  void axpy  ( Rep& res, const Type_t& a, const Rep& A, const Rep& X,
                const Type_t& b, const Rep& Y ) const;
-  // A*X + Y 
+  // A*X + Y
   void axpy  ( Rep& res, const Rep& A, const Rep& X, const Rep& Y ) const;
 
   // -- Element wise operation:
@@ -139,4 +149,6 @@ public:
   ostream& write( ostream& s, const Rep& r ) const;
 };
 
+} // Givaro
+
 #endif
