@@ -1,21 +1,29 @@
-#ifndef _INDETER_H_
-#define _INDETER_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/library/poly1/givindeter.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givindeter.h,v 1.4 2008-04-08 11:43:11 jgdumas Exp $
+// $Id: givindeter.h,v 1.6 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
-// Description:
-// - indeterminates for polynomial manipulation
+/** @file givindeter.h
+ * @ingroup poly1
+ * @brief indeterminates for polynomial manipulation
+ */
+#ifndef __GIVARO_indeter_H
+#define __GIVARO_indeter_H
 
 #include <iostream>
 #include <string>
 
+namespace Givaro {
+
+	//! Indeterminate
 class Indeter {
 public :
-     
+
   // -- Cstor: recopy the string
  Indeter(const std::string & x="") : name(x){}
   // -- Cstor: recopy the string
@@ -25,7 +33,7 @@ public :
 
   // -- Dstor
   ~Indeter(){}
- 
+
   // -- assignement
   Indeter& operator= (const Indeter& s);
 
@@ -36,7 +44,7 @@ public :
  // for multivariate polynomials.
  int compare(const Indeter& b)  const;
 
-  // -- methods	
+  // -- methods
   friend std::ostream& operator<< (std::ostream& o, const Indeter& X);
   friend std::istream& operator>> (std::istream& o, Indeter& X);
 
@@ -44,23 +52,25 @@ protected:
   std::string name;
 };
 
-  // Inline members functions :
-inline int operator==(const Indeter& i1, const Indeter &i2) 
+
+  //! @bug put elsewere. Inline members functions :
+inline int operator==(const Indeter& i1, const Indeter &i2)
   { return i1.compare(i2) ==0; }
 
-inline int operator!=(const Indeter& i1, const Indeter &i2) 
+inline int operator!=(const Indeter& i1, const Indeter &i2)
   { return i1.compare(i2) !=0; }
 
-inline int operator<= (const Indeter& i1, const Indeter &i2)  
+inline int operator<= (const Indeter& i1, const Indeter &i2)
   { return i1.compare(i2) <=0; }
 
-inline int operator<  (const Indeter& i1, const Indeter &i2) 
+inline int operator<  (const Indeter& i1, const Indeter &i2)
   { return i1.compare(i2) <0; }
 
-inline int operator>= (const Indeter& i1, const Indeter &i2) 
+inline int operator>= (const Indeter& i1, const Indeter &i2)
   { return i1.compare(i2) >=0; }
 
 inline int operator>  (const Indeter& i1, const Indeter &i2)
   { return i1.compare(i2) >0; }
 
-#endif
+  } // Givaro
+#endif // __GIVARO_indeter_H
