@@ -1,13 +1,19 @@
-#ifndef _GIV_POLY1_H_
-#define _GIV_POLY1_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/library/poly1/givpoly1.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givpoly1.h,v 1.1.1.1 2004/05/12 16:08:24 jgdumas Exp $
+// $Id: givpoly1.h,v 1.3 2011-02-02 16:23:56 bboyer Exp $
 // ==========================================================================
-// Description:
+/** @file givpoly1.h
+ * @ingroup poly1
+ * @brief NO DOC
+ */
+#ifndef __GIVARO_poly1_H
+#define __GIVARO_poly1_H
 
 #include "givaro/giverror.h"
 #include "givaro/givarray0.h"
@@ -15,6 +21,7 @@
 #include "givaro/giviterator.h"
 #include "givaro/givops.h"
 
+namespace Givaro {
 
 // ==========================================================================
 // --
@@ -26,10 +33,12 @@ template<class Domain, class StorageTag> class Poly1Dom;
 template<class Domain> class Poly1Dom<Domain,Dense>;
 template<class Domain> class Poly1Dom<Domain,Sparse>;
 
+} // Givaro
+
 #include "givaro/givpoly1dense.h"
 // #include "givaro/givvectorsparse.h"
 // -- should be included in specialized class #include "givaro/givvectops.inl"
 #include "givaro/givpoly1denseops.inl"
 // #include "givaro/givvectsparseops.inl"
 
-#endif
+#endif // __GIVARO_poly1_H
