@@ -1,24 +1,28 @@
-#ifndef _GIV_OPERATION_H_
-#define _GIV_OPERATION_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/library/tools/givops.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givops.h,v 1.2 2005/04/28 11:24:21 jgdumas Exp $
+// $Id: givops.h,v 1.3 2009-09-17 14:28:23 jgdumas Exp $
 // ==========================================================================
 // Description:
 // Class version of operations on a group F. By default use arithmetic operator
-// 
+#ifndef __GIVARO_operation_H
+#define __GIVARO_operation_H
+//
 #include "givaro/givconfig.h"
 #include "givaro/giviterator.h"
 
+namespace Givaro {
 template<class Domain>
 struct BaseOP {
   typedef typename 	Domain::Rep 	Type_t;
   typedef 		Domain 		Domain_t;
   const Domain& _domain;
-  BaseOP( const Domain& D ) : _domain(D) {} 
+  BaseOP( const Domain& D ) : _domain(D) {}
 };
 
 template<class Domain>
@@ -26,8 +30,8 @@ struct CopyOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   CopyOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& v1, const Type_t& v2) const {  
-    BaseOP<Domain>::_domain.assign(v1, v2); 
+  void operator() (Type_t& v1, const Type_t& v2) const {
+    BaseOP<Domain>::_domain.assign(v1, v2);
   }
 };
 
@@ -38,9 +42,9 @@ struct MulOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   MulOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const 
+  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const
   { BaseOP<Domain>::_domain.mul( res, v1, v2); }
-  void operator() (Type_t& res, const Type_t& v1 ) const 
+  void operator() (Type_t& res, const Type_t& v1 ) const
   { BaseOP<Domain>::_domain.mulin( res, v1 ); }
 };
 
@@ -49,9 +53,9 @@ struct DivOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   DivOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const 
+  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const
   { BaseOP<Domain>::_domain.div( res, v1, v2); }
-  void operator() (Type_t& res, const Type_t& v1) const 
+  void operator() (Type_t& res, const Type_t& v1) const
   { BaseOP<Domain>::_domain.divin( res, v1 ); }
 };
 
@@ -60,9 +64,9 @@ struct ModOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   ModOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const 
+  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const
   {  BaseOP<Domain>::_domain.mod( res, v1, v2); }
-  void operator() (Type_t& res, const Type_t& v1) const 
+  void operator() (Type_t& res, const Type_t& v1) const
   {  BaseOP<Domain>::_domain.modin( res, v1 ); }
 };
 
@@ -71,9 +75,9 @@ struct AddOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   AddOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const 
+  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const
   {  BaseOP<Domain>::_domain.add( res, v1, v2 ); }
-  void operator() (Type_t& res, const Type_t& v1) const 
+  void operator() (Type_t& res, const Type_t& v1) const
   {  BaseOP<Domain>::_domain.addin( res, v1 ); }
 };
 
@@ -82,9 +86,9 @@ struct SubOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   SubOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const 
+  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2) const
   { BaseOP<Domain>::_domain.sub( res, v1, v2 ); }
-  void operator() (Type_t& res, const Type_t& v1) const 
+  void operator() (Type_t& res, const Type_t& v1) const
   { BaseOP<Domain>::_domain.subin( res, v1 ); }
 };
 
@@ -93,9 +97,9 @@ struct NegOp : public BaseOP<Domain> {
   typedef typename 	BaseOP<Domain>::Type_t 	Type_t;
   typedef 		Domain 			Domain_t;
   NegOp( const Domain& D ) : BaseOP<Domain>(D) {}
-  void operator() (Type_t& res, const Type_t& v1) const 
+  void operator() (Type_t& res, const Type_t& v1) const
   { BaseOP<Domain>::_domain.neg( res, v1 ); }
-  void operator() (Type_t& res ) const 
+  void operator() (Type_t& res ) const
   { BaseOP<Domain>::_domain.negin( res, res ); }
 };
 
@@ -106,7 +110,7 @@ struct MulAddOp : public BaseOP<Domain> {
   MulAddOp( const Domain& D ) : BaseOP<Domain>(D) {}
   void operator()(Type_t& res, const Type_t& v1, const Type_t& v2, const Type_t& v3) const
   { BaseOP<Domain>::_domain.axpy( res, v1, v2, v3 ); }
-  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2 ) const 
+  void operator() (Type_t& res, const Type_t& v1, const Type_t& v2 ) const
   { BaseOP<Domain>::_domain.axpyin( res, v1, v2 ); }
 };
 
@@ -136,5 +140,6 @@ struct Curried2 : public OP {
   void operator()(Type_t& v1) { OP::operator()(v1, _val); }
 };
 
+} // Givaro
 
 #endif
